.. _viewfactors:

viewfactors
-----------

The viewfactors sub-package of pvfactors implements the methods used to calculate view factors from pvfactors PV array objects.

calculator
^^^^^^^^^^

.. automodule:: pvfactors.viewfactors.calculator
   :no-members:
   :no-inherited-members:
   :noindex:

.. autosummary::
   :toctree: generated/
   :nosignatures:

   ~pvfactors.viewfactors.calculator.VFCalculator

timeseries view factor methods
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: pvfactors.viewfactors.vfmethods
   :no-members:
   :no-inherited-members:
   :noindex:

.. autosummary::
   :toctree: generated/
   :nosignatures:

   ~pvfactors.viewfactors.vfmethods.VFTsMethods

view factor aoi methods
^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: pvfactors.viewfactors.aoimethods
   :no-members:
   :no-inherited-members:
   :noindex:

.. autosummary::
   :toctree: generated/
   :nosignatures:

   ~pvfactors.viewfactors.aoimethods.AOIMethods
